@@ -1,4 +1,5 @@
 from tkinter import *
+from tkinter import font
 import tkinter.messagebox
 
 window = Tk()
@@ -43,4 +44,10 @@ def createMessageBoxWarning(Title, Text):
     tkinter.messagebox.showwarning(Title, Text)
 
 def setBackground(Color):
-    window.configure(background=Color)
\ No newline at end of file
+    window.configure(background=Color)
+
+def updateScreen():
+    window.update()
+
+def updateIdleTasks():
+    window.update_idletasks()
\ No newline at end of file
